"""
Author:         David Szybala
Website:        www.davidszybala.com
Alt Website:    www.twistedgerbil.com
Program:        remove_namespaces.py
Date:           10/16/14
Description:    This script will remove all namespaces in the scene
Installation:   Place this file in your maya scripts directory
                (e.g. ..\My Documents\maya\scripts) then run the following
                python commands:
                    import remove_namespaces
                    remove_namespaces.main()
"""
import maya.cmds as cmds
from sys import stdout


class RemoveNamespaces(object):
    @staticmethod
    def get_namespaces():
        """Returns a list of all namespaces in the current namespace. NOTE: The
        default namespaces are removed from the return value"""
        defaults = ['UI', 'shared']
        namespaces = [x for x in cmds.namespaceInfo(recurse=True, listOnlyNamespaces=True) if x not in defaults]
        namespaces.sort(key=lambda x: x.count(':'))

        return namespaces

    @staticmethod
    def remove_namespace(name):
        """Removes the namespace 'name' Returns True on success"""
        success = True

        try:
            cmds.namespace(moveNamespace=(name, ':'), force=True)
            cmds.namespace(removeNamespace=name)
        except:
            success = False

        return success

    def remove_all_namespaces(self):
        """Removes all namespaces from the scene. Returns the number of
        errors"""
        # CRITICAL! Set the root namespace now!
        cmds.namespace(set=':')

        all_namespaces = self.get_namespaces()
        error_counter = 0

        for current in reversed(all_namespaces):
            if not (self.remove_namespace(current)):
                error_counter += 1

        return error_counter


def main():
    """Main entry point. Executes the script"""
    rn = RemoveNamespaces()
    result = rn.remove_all_namespaces()

    if result == 0:
        stdout.write('INFO: All namespaces have been removed')
    else:
        print('WARNING: The following namespaces could not be removed:')
        for current in rn.get_namespaces():
            print(current)
        stdout.write('WARNING: Some namespaces could not be removed. Check script editor')


if __name__ == '__main__':
    main()
